var webtools = {
	
	/**
	 * 通用打开各模块的详情页面
	 * @param {String} modName 模块名称
	 * @param {Object} extData 目标ID
	 * @param {String} eventName 事件名
	 */
	openDtlWeb: function(modName, extData, eventName) {
		var webUrl = '../../' + modName + '/view/' + modName + '-detail';
		eventName = modName + 'Change';
		webtools.openRptWeb(webUrl,extData,eventName);
	},
	
	/**
	 * 通用打开预载页面
	 * @param {String} webUrl 目标页面路径(不含.html)
	 * @param {Object} extData 需要传递的数据对象
	 * @param {String} eventName 事件名
	 */
	openRptWeb:function(webUrl, extData, eventName){
		var webId = webUrl;
		if(~webId.indexOf('/')){
			webId = webId.substr(webId.lastIndexOf('/') + 1);
		}
		var dtlWeb = plus.webview.getWebviewById(webId);
		if(!dtlWeb) {
			dtlWeb = mui.preload({
				url: webUrl + '.html',
				id: webId,
			});
		}
		setTimeout(function() {
			mui.fire(dtlWeb, eventName, {
				data: extData
			});
			dtlWeb.show('pop-in', 300);
		}, 300)
	},
	
	/**
	 * 通用打开一次性使用页面
	 * @param {String} webUrl 目标页面路径(不含.html)
	 * @param {Object} extData 传递数据
	 * @param {String} anima 页面切换动画
	 * @param {int} drtTime 动画持续时间
	 */
	openSingleWeb: function(webUrl, extData, anima, drtTime) {
		anima = anima || "pop-in";
		drtTime = drtTime || 300;
		var webId = webUrl;
		if(~webId.indexOf('/')){
			webId = webId.substr(webId.lastIndexOf('/') + 1);
		}
  		mui.openWindow({
  			url:webUrl + '.html',
  			id:webId,
  			extras:{
				data:extData
			},
  			styles:{
  				scrollIndicator:'none'
  			},
  			show:{
		    	aniShow:anima,
		    	duration:drtTime
		    },
		    createNew:false,
			waiting: {
				autoShow: false
			}
  		})
	},


	/**
	 * @param {需要关闭web的id} webId
	 */
	closeWeb: function(webId) {
		var webView = plus.webview.getWebviewById(webId);
		if(webView) {
			webView.close('none');
		}
	}
};

//APP工具类
var apptools = {
	
	/*格式化富文本*/
	 fmtRichText:function(content,imgPaths){
	 	var str = '';
		for(var name in imgPaths){
			var imageId = '[#' + name + '#]';
			content = content.replace(imageId,'<br><img src="' + imgPaths[name].path + '"/>');
		}
		str = content.replace(/[#imgage[0-9]+#]/g,'');
		return str;
	},
	
	/*去除数组里重复的元素*/
	uniqueArr:function(array){
	  	var r = [];
	  	for(var i = 0, l = array.length; i < l; i++) {
		    for(var j = i + 1; j < l; j++)
		      	if (array[i] === array[j]) j = ++i;
		   		r.push(array[i]);
	  	}
	  	return r;
	},
	
	/*把版本号转为3位有效数字*/
	fmtVersion:function(str){
		return parseFloat('0.'+'9'.replace(/\./g,'').slice(0,3))*1000;
	},
	
	/*选中控件字体颜色改变*/
	setOkcolor:function(dom){
		dom.style.color = '#5AE05A';
	},

	/**
	 * 时间戳解析 必须要导入moment.js才能使用，否则报错
	 * @param {int} unixTime
	 * @param {Object} type
	 */
	fmtUnixTime: function(unixTime, type) {
		type = type ? 'YYYY-M-D h:m' : 'L';
		return moment.unix(unixTime).format(type);
	},

	//给页面注册一个失去焦点事件，专用于解决ios系统下input控件不会自动失去焦点
	webBlur: function() {
		if(mui.os.ios){
			window.addEventListener('touchstart', function(e) {
				if(e.target.tagName != "INPUT"){
					document.activeElement.blur();
				}
			})
		}
	},
	
	/*验证码验证*/
	checkScore: function(need,have) {
		if(have - need < 0) {
			mui.alert('余额不足');
			return false;
		}
		return true;
	},
	
	/*验证码验证*/
	checkVerify: function(verify) {
		if(!verify.trim()) {
//			laizhipei 屏蔽验证码 2-10
//			mui.alert('验证码不能为空');
//			return false;
			return true;
		}
		return true;
	},

	/*密码验证*/
	checkPassword: function(password) {
		var pswRegx = /^\w{6,20}$/;
		if(!pswRegx.test(password)) {
			mui.alert('密码格式错误,需要6-20位非特殊字符');
			return false;
		}
		return true;
	},

	/*验证手机*/
	checkMobile: function(tel) {
		var mblRegx = /^1[3|4|5|7|8]\d{9}$/;
		if(!mblRegx.test(tel)) {
			mui.alert('请输入正确的手机号码');
			return false;
		}
		return true;
	},

	/*邮箱验证*/
	checkEmail: function(email) {
		var emlRegx = /(^[a-zA-Z0-9_\.\-]+@[a-zA-Z0-9_-]+\.[a-zA-Z0-9_-]+$)|(^$)/;
		if(!email || !emlRegx.test(email)){
			mui.alert('请输入正确的邮箱');
			return false;
		}
		return true;
	},

	/**
	 * 检查用户组权限(判断group1和group2是否有交集)
	 * @param {Array} group1
	 * @param {Array} group2
	 */
	checkPms: function(group1, group2) {
		for(var i in group1) {
			for(var j in group2) {
				if(group1[i] == group2[j]) {
					return true;
				}
			}
		}
		return false;
	},

	//关闭页面
	finish: function(thisWeb) {
		thisWeb.close();
	},

	/**
	 * 判断指定控件是否显示
	 */
	domIsVisible: function(dom) {
		if(dom.style.display == "block" || dom.style.display == "") {
			return true;
		} else if(dom.style.display == "none") {
			return false;
		}
	},

	/**
	 * 生成论坛形式楼层
	 */
	createFloor: function(floor) {
		if(floor == 1) {
			floor = '沙发';
		} else if(floor == 2) {
			floor = '板凳';
		} else if(floor == 3) {
			floor = '地板';
		} else {
			floor = '第' + floor + '楼';
		}
		return floor;
	},

	/*打开软键盘*/
	showKeyboard: function() {
		if(mui.os.ios) {
			var webView = plus.webview.currentWebview().nativeInstanceObject();
			webView.plusCallMethod({
				"setKeyboardDisplayRequiresUserAction": false
			});
		} else {
			var Context = plus.android.importClass("android.content.Context");
			var InputMethodManager = plus.android.importClass("android.view.inputmethod.InputMethodManager");
			var main = plus.android.runtimeMainActivity();
			var imm = main.getSystemService(Context.INPUT_METHOD_SERVICE);
			imm.toggleSoftInput(0, InputMethodManager.SHOW_FORCED);
			//var view = ((ViewGroup)main.findViewById(android.R.id.content)).getChildAt(0);
			imm.showSoftInput(main.getWindow().getDecorView(), InputMethodManager.SHOW_IMPLICIT);
			//alert("ll");
		}
	},

	/*时间戳格式化*/
	formatDate: function(tempDate) {
		var year = tempDate.getFullYear();
		var month = tempDate.getMonth() + 1;
		var date = tempDate.getDate();
		var hour = tempDate.getHours();
		var minute = tempDate.getMinutes();
		var second = tempDate.getSeconds();
		return month + "-" + date + "   " + hour + ":" + minute;
	},

	/*给页面注册一个双击返回键退出APP的事件*/
	exitApp: function() {
		//处理逻辑：1秒内，连续两次按返回键，则退出应用；

		var first = null;
		mui.back = function() {
			//首次按键，提示‘再按一次退出应用’
			if(!first) {
				if(mui.os.ios) {
					document.activeElement.blur();
				}
				first = new Date().getTime();
				mui.toast('再按一次退出应用');
				setTimeout(function() {
					first = null;
				}, 1000);
			} else {
				if(new Date().getTime() - first < 1000) {
					plus.runtime.quit();
				}
			}
		};
	},

	/*向数组的首位添加一个非重复的元素*/
	addEle: function(arr, ele) {
		if(ele != '' && arr.indexOf(ele) < 0) {
			arr.unshift(ele);
		}
		return arr;
	},
	
	//创建一个本地通知消息
	creatMsg: function(msg) {
		var pushSwich = myStorage.getItem('push_in_notice');
		var	options = {
			title: msg.title,
			cover: false
		};

		if(!pushSwich || pushSwich== 1) {
			plus.push.createMessage(msg.content, JSON.stringify(msg.data), options);
		}
	},
	
	/**
	 * 复写MUI一级选择器的隐藏方法，用于自定义样式的选择器触发样式
	 * 筑易触发器结构样式
	 */
	pickerHide:function(picker,dom){
		picker.hide = function(){
			dom.parentNode.classList.remove('mui-active');
			var self = this;
			if (self.disposed) return;
			self.panel.classList.remove(mui.className('active'));
			self.mask.close();
			document.body.classList.remove(mui.className('poppicker-active-for-page'));
			//处理物理返回键
			mui.back = self.__back;
		}
	}
};

/*按钮计时器对象*/
var DecTime = function(obj,time){
	$this = this;
    this.Obj = obj;
    this.initText = obj.innerHTML;
    this.time = time;
    this.setTime = function(time){
    	$this.time = time;
    };
    this.dec_time = function(){
        if($this.time > 0){
        	$this.Obj.disabled = true;
            $this.Obj.innerHTML = "重新获取"+$this.time--+'S';
            setTimeout($this.dec_time,1000)
        }else{
            $this.Obj.innerHTML = $this.initText;
            $this.Obj.disabled = false;
        }
    };
    this.dec_time();
    return $this;
};

/*loading的加载和显示*/
var changePage = function(loadDiv, pageDiv, loading) {
	loadDiv.style.display = loading ? 'block' : 'none';
	pageDiv.style.display = loading ? 'none' : 'block';
};

/**
 * 回到顶部
 */
var goTop = function(thisWeb) {
	var headChidWebArr = thisWeb.children();
	if(headChidWebArr.length >= 1) { //判断是否存在子页面，如果不存在则直接对本页面进行回顶操作
		for(index in headChidWebArr) {
			if(headChidWebArr[index].isVisible()) { //只对当前显示的页面进行回顶操作      				
				headChidWebArr[index].evalJS('window.scrollTo(0,0)');
			}
		}
	} else {
		thisWeb.evalJS('mui("#scroll_wrapper").scroll().scrollTo(0,0)');
	}
};

/*判断webview是否已经生成*/
var is_create = function(webId) {
	return !!plus.webview.getWebviewById(webId);
};

var createMsk = function() {
	masking = document.createElement('div');
	var sHeight = plus.screen.resolutionHeight;
	var fHeight = parseInt(show_comment.style.height);
	var mHeight = sHeight - fHeight;
	masking.style.height = (mHeight - 20) + 'px'
	masking.className = 'masking';
	document.body.appendChild(masking);
	masking.addEventListener('tap', function() {
		show_comment.style.display = 'none';
		show_foot.style.display = 'block';
		masking.style.display = 'none';
		//关闭软键盘
		document.activeElement.blur();
	})
}